from collocation import *

# Heating power [W]
Q = 1e3

# Amount of Glogg [mol]
n = SX.sym('n')

# Molar concentrations [dimensionless]
c = SX.sym('c')

# Heat of evaporation [W/mol]
h = 40e3

# Glogg rate of change
ndot = -Q/h

# Boiling temperature
T = SX.sym('T')

# Vapor pressure
A1 = 8.1
B1 = 1730.
C1 = 233.
A2 = 8.2
B2 = 1643.
C2 = 230.
p1 = 10**(A1-B1/(C1+T))
p2 = 10**(A2-B2/(C2+T))

# Air pressure [mmHg]
p0 = 760.
alg = p1*(1-c) + p2*c - p0

# Concentration rate of change
cdot = -Q/(h*n)*(c*p2/p0 - c)

# Initial conditions
n0 = 250 # [mol]
c0 = 0.2

# Find initial temperature
rfp = Function('rfp', [T, n, c], [alg])
rf = rootfinder('rf', 'newton', rfp)
[T0] = rf([100, n0, c0])
print ' --- Consistent initial conditions ---'
print 'T0 = ', T0

# Simulate for 2 hours
tf = 7200.
dae = {'x':vertcat((n,c)), 'z':T, 'ode':tf*vertcat((ndot,cdot)), 'alg':alg}
F1 = integrator('solver', 'idas', dae)
sol = F1({'x0':[n0,c0], 'z0':T0})
print ' --- IDAS ---'
print 'x(tf): ', sol['xf']
print 'z(tf): ', sol['zf']

# Collocation integrator
M = 100  # IRK steps per interval

# Create discrete time dynamics
F2 = collocation(dae, 1., M)

# Evaluate at a test point
sol2 = F2({'x0':[n0,c0], 'z0':T0})
print ' --- Collocation integrator ---'
print 'x(tf): ', sol['xf']
print 'z(tf): ', sol['zf']
